%define _unpackaged_files_terminate_build 1
%define _stripped_files_terminate_build 1
%set_verify_elf_method strict

%define oname ipython

%def_without doc
%def_with check

Name: ipython3
Version: 8.32.0
Release: alt1
Summary: An enhanced interactive Python 3 shell
License: BSD-3-Clause
Group: Development/Python3
Url: https://ipython.org
Vcs: https://github.com/ipython/ipython.git

BuildArch: noarch

Source: %name-%version.tar

%add_findreq_skiplist %python3_sitelibdir/IPython/utils/eventful.py

BuildRequires(pre): rpm-build-python3
BuildRequires: python3(prompt_toolkit)
BuildRequires: python3(stack_data)
BuildRequires: python3(setuptools)
BuildRequires: python3(wheel)

%if_with check
BuildRequires: python3(pytest)
BuildRequires: python3(pytest-asyncio)
BuildRequires: python3(testpath)
BuildRequires: python3(traitlets)
BuildRequires: python3(pygments)
BuildRequires: python3(pexpect)
BuildRequires: python3-modules-sqlite3
BuildRequires: python3(jedi)
BuildRequires: python3(pickleshare)
BuildRequires: /dev/pts
BuildRequires: /proc
BuildRequires: git
%endif

%if_with doc
BuildRequires(pre): rpm-macros-sphinx3
BuildRequires: python3-module-sphinx-sphinx-build-symlink
BuildRequires: python3(sphinx_rtd_theme)
BuildRequires: python3(ipykernel)
BuildRequires: python3(matplotlib)
BuildRequires: python3-module-matplotlib-inline
BuildRequires: python3-module-matplotlib-tk
BuildRequires: python3(stack_data)
BuildRequires: python3(exceptiongroup)
BuildRequires: python3(testpath)
BuildRequires: python3(numpy)
BuildRequires: python3(prompt_toolkit)
BuildRequires: python3(pickleshare)
BuildRequires: python3(jedi)
BuildRequires: python3-module-matplotlib-sphinxext
BuildRequires: python3-module-sphinx-devel
BuildRequires: /proc
# Some trouble with graphviz generating 'Inheritance diagram'
#BuildRequires: graphviz
%endif

%add_python3_req_skip __main__
%add_python3_req_skip Gnuplot Numeric bzrlib foolscap nose setuptools twisted
%add_python3_req_skip msvcrt wx gtk gobject compiler OpenGL oct2py rpy2
%add_python3_req_skip System clr
%add_python3_req_skip ipyparallel.apps.daemonize

Requires: python3-module-%oname = %EVR

Conflicts: ipython

%description
IPython provides a replacement for the interactive Python interpreter with
extra functionality.

Main features:
* Comprehensive object introspection.
* Input history, persistent across sessions.
* Caching of output results during a session with automatically generated
  references.
* Readline based name completion.
* Extensible system of 'magic' commands for controlling the environment and
  performing many tasks related either to IPython or the operating system.
* Configuration system with easy switching between different setups (simpler
  than changing $$PYTHONSTARTUP environment variables every time).
* Session logging and reloading.
* Extensible syntax processing for special purpose situations.
* Access to the system shell with user-extensible alias system.
* Easily embeddable in other Python programs.
* Integrated access to the pdb debugger and the Python profiler.

%package doc
Summary: IPython documentation
Group: Development/Python3

%description doc
IPython provides a replacement for the interactive Python interpreter with
extra functionality.

This package contains IPython documentation (html and PDF formats).

%package examples
Summary: IPython examples
Group: Development/Python3

%description examples
IPython provides a replacement for the interactive Python interpreter with
extra functionality.

This package contains examples for IPython.

%package -n python3-module-%oname
Summary: An enhanced interactive Python 3 shell
Group: Development/Python3
Requires: python3(matplotlib_inline) python3(pickleshare)

%description -n python3-module-%oname
IPython provides a replacement for the interactive Python interpreter with
extra functionality.

This package contains modules for Python-3.

%package -n python3-module-%oname-tests
Summary: An enhanced interactive Python 3 shell
Group: Development/Python3

%description -n python3-module-%oname-tests
IPython provides a replacement for the interactive Python interpreter with
extra functionality.

This package contains tests for Python-3.

%prep
%setup

%if_with doc
%prepare_sphinx3 docs
ln -s ../objects.inv docs/source/
%endif

%build
%pyproject_build

%install
%pyproject_install

%if_with doc
install -d %buildroot%_docdir/%name
cp docs/source/*.txt %buildroot%_docdir/%name/

export PYTHONPATH=%buildroot%python3_sitelibdir
%make -C docs html
cp -R docs/build/html/* examples %buildroot%_docdir/%name/
%endif

%check
export PYTHONPATH=%buildroot%python3_sitelibdir
# Ensure that the user's .pythonrc.py is not invoked during any tests.
export PYTHONSTARTUP=""
# Scale timeouts 4 times
export IPYTHON_TESTING_TIMEOUT_SCALE=4
# To prevent _pytest.pathlib.ImportPathMismatchError, we are
# testing directly in buildroot
pushd %buildroot%python3_sitelibdir/IPython
py.test-3 -v
rm -rf .pytest_cache __pycache__/tmp*.pyc
popd

%files
%doc COPYING.rst LICENSE
%doc README.rst
%_bindir/*
%_man1dir/*
%if_with doc
%dir %_docdir/%name
%_docdir/%name/*.txt
%endif

%files -n python3-module-%oname
%python3_sitelibdir/IPython
%python3_sitelibdir/%oname-%version.dist-info
# everything except for skipdoctest.py from IPython/testing is packaged into tests package
%exclude %python3_sitelibdir/IPython/testing/plugin
%exclude %python3_sitelibdir/IPython/testing/__init__.py
%exclude %python3_sitelibdir/IPython/testing/decorators.py
%exclude %python3_sitelibdir/IPython/testing/globalipapp.py
%exclude %python3_sitelibdir/IPython/testing/ipunittest.py
%exclude %python3_sitelibdir/IPython/testing/tools.py
%exclude %python3_sitelibdir/IPython/testing/__pycache__/__init__.*
%exclude %python3_sitelibdir/IPython/testing/__pycache__/decorators.*
%exclude %python3_sitelibdir/IPython/testing/__pycache__/globalipapp.*
%exclude %python3_sitelibdir/IPython/testing/__pycache__/ipunittest.*
%exclude %python3_sitelibdir/IPython/testing/__pycache__/tools.*
%exclude %python3_sitelibdir/IPython/*/tests
%exclude %python3_sitelibdir/IPython/conftest.py
%exclude %python3_sitelibdir/IPython/__pycache__/conftest.*

%files -n python3-module-%oname-tests
%python3_sitelibdir/IPython/testing/plugin
%python3_sitelibdir/IPython/testing/__init__.py
%python3_sitelibdir/IPython/testing/decorators.py
%python3_sitelibdir/IPython/testing/globalipapp.py
%python3_sitelibdir/IPython/testing/ipunittest.py
%python3_sitelibdir/IPython/testing/tools.py
%python3_sitelibdir/IPython/testing/__pycache__/__init__.*
%python3_sitelibdir/IPython/testing/__pycache__/decorators.*
%python3_sitelibdir/IPython/testing/__pycache__/globalipapp.*
%python3_sitelibdir/IPython/testing/__pycache__/ipunittest.*
%python3_sitelibdir/IPython/testing/__pycache__/tools.*
%python3_sitelibdir/IPython/*/tests
%python3_sitelibdir/IPython/conftest.py
%python3_sitelibdir/IPython/__pycache__/conftest.*

%if_with doc
%files doc
%_docdir/%name
%exclude %_docdir/%name/*.txt
%exclude %_docdir/%name/examples

%files examples
%dir %_docdir/%name
%_docdir/%name/examples
%endif

%changelog
